==> pdf-model-1.23.4-sources.jar: org/verapdf/model/xmplayer/PDFAIdentification.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.xmplayer;
		
import org.verapdf.model.baselayer.Object;
import java.util.List;

		
public interface PDFAIdentification extends XMPObject {
	

	/**  value of ‘part’ property from PDF/A Identification schema
	 */
	public Long getpart();

	/**  value of ‘conformance’ property from PDF/A Identification schema
	 */
	public String getconformance();

	/**  string value of ‘rev’ property from PDF/A Identification schema
	 */
	public String getrev();

	/**  namespace prefix for the ‘part’ property from PDF/A Identification schema
	 */
	public String getpartPrefix();

	/**  namespace prefix for the ‘conformance’ property from PDF/A Identification schema
	 */
	public String getconformancePrefix();

	/**  namespace prefix for the ‘amd’ property from PDF/A Identification schema
	 */
	public String getamdPrefix();

	/**  namespace prefix for the ‘corr’ property from PDF/A Identification schema
	 */
	public String getcorrPrefix();

	/**  namespace prefix for the ‘rev’ property from PDF/A Identification schema
	 */
	public String getrevPrefix();
}

==> pdf-model-1.26.1-sources.jar: org/verapdf/model/xmplayer/PDFAIdentification.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.xmplayer;
		
import org.verapdf.model.baselayer.Object;
import java.util.List;

		
/**
*/
public interface PDFAIdentification extends XMPObject {
	

	/**
	* value of ‘part’ property from PDF/A Identification schema
	*/
	public Long getpart();

	/**
	* value of ‘conformance’ property from PDF/A Identification schema
	*/
	public String getconformance();

	/**
	* string value of ‘rev’ property from PDF/A Identification schema
	*/
	public String getrev();

	/**
	* namespace prefix for the ‘part’ property from PDF/A Identification schema
	*/
	public String getpartPrefix();

	/**
	* namespace prefix for the ‘conformance’ property from PDF/A Identification schema
	*/
	public String getconformancePrefix();

	/**
	* namespace prefix for the ‘amd’ property from PDF/A Identification schema
	*/
	public String getamdPrefix();

	/**
	* namespace prefix for the ‘corr’ property from PDF/A Identification schema
	*/
	public String getcorrPrefix();

	/**
	* namespace prefix for the ‘rev’ property from PDF/A Identification schema
	*/
	public String getrevPrefix();
}
